==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/history/translations/history_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Im Verlauf speichern</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Zustandänderungen speichern</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Zustandänderungen werden im Verlauf gespeichert</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Verlauf zeigen</translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BuddyStatusDatesModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatDatesModel</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished">Chat</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>View Chat History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryChatsModel</name>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMSes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation type="unfinished">Verlauf</translation>
    </message>
    <message>
        <source>&amp;Remove entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>by date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no history storage module loaded!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsDatesModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/history/translations/history_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Im Verlauf speichern</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Zustandänderungen speichern</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Zustandänderungen werden im Verlauf gespeichert</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Verlauf zeigen</translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BuddyStatusDatesModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatDatesModel</name>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryChatsModel</name>
    <message>
        <source>Statuses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SMSes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation type="unfinished">Verlauf</translation>
    </message>
    <message>
        <source>&amp;Remove entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>by date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no history storage plugin loaded!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsDatesModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
